<form action="{% url change_plan %}" method="POST">
    {% csrf_token %}
    <input type="hidden" name="plan_code" value="{{ plan_code }}">
    <input type="submit" name="submit" value="Change plan">
</form>